@@ -233,57 +233,3 @@ func TestGatewayConfiguration(t *testing.T) {
 		})
 	}
 }
-
-func TestReconcileGatewayConfiguration(t *testing.T) {
-	cases := []struct {
-		name   string
-		want   bool
-		config *corev1.ConfigMap
-	}{{
-		name: "enable ReconcileExternalGateway",
-		want: true,
-		config: &corev1.ConfigMap{
-			ObjectMeta: metav1.ObjectMeta{
-				Namespace: system.Namespace(),
-				Name:      IstioConfigName,
-			},
-			Data: map[string]string{
-				"reconcileExternalGateway": "true",
-			},
-		},
-	}, {
-		name: "disable ReconcileExternalGateway",
-		want: false,
-		config: &corev1.ConfigMap{
-			ObjectMeta: metav1.ObjectMeta{
-				Namespace: system.Namespace(),
-				Name:      IstioConfigName,
-			},
-			Data: map[string]string{
-				"reconcileExternalGateway": "false",
-			},
-		},
-	}, {
-		name: "disable by default",
-		want: false,
-		config: &corev1.ConfigMap{
-			ObjectMeta: metav1.ObjectMeta{
-				Namespace: system.Namespace(),
-				Name:      IstioConfigName,
-			},
-			Data: map[string]string{},
-		},
-	}}
-
-	for _, tt := range cases {
-		t.Run(tt.name, func(t *testing.T) {
-			istio, err := NewIstioFromConfigMap(tt.config)
-			if err != nil {
-				t.Fatalf("Test: %q; NewIstioFromConfigMap() error = %v", tt.name, err)
-			}
-			if tt.want != istio.ReconcileExternalGateway {
-				t.Fatalf("Unexpected result (-want %t, +got %t)", tt.want, istio.ReconcileExternalGateway)
-			}
-		})
-	}
-}
