@@ -28,7 +28,8 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	corev1listers "k8s.io/client-go/listers/core/v1"
 
-	"knative.dev/pkg/apis/istio/v1alpha3"
+	istiov1alpha3 "istio.io/api/networking/v1alpha3"
+	"istio.io/client-go/pkg/apis/networking/v1alpha3"
 	fakekubeclient "knative.dev/pkg/client/injection/kube/client/fake"
 	fakeserviceinformer "knative.dev/pkg/client/injection/kube/informers/core/v1/service/fake"
 	"knative.dev/pkg/kmeta"
@@ -59,87 +60,85 @@ var selector = map[string]string{
 }
 
 var gateway = v1alpha3.Gateway{
-	Spec: v1alpha3.GatewaySpec{
+	Spec: istiov1alpha3.Gateway{
 		Servers: servers,
 	},
 }
 
-var servers = []v1alpha3.Server{
-	{
-		Hosts: []string{"host1.example.com"},
-		Port: v1alpha3.Port{
-			Name:     "test-ns/ingress:0",
-			Number:   443,
-			Protocol: v1alpha3.ProtocolHTTPS,
-		},
-		TLS: &v1alpha3.TLSOptions{
-			Mode:              v1alpha3.TLSModeSimple,
-			ServerCertificate: "tls.crt",
-			PrivateKey:        "tls.key",
-		},
-	}, {
-		Hosts: []string{"host2.example.com"},
-		Port: v1alpha3.Port{
-			Name:     "test-ns/non-ingress:0",
-			Number:   443,
-			Protocol: v1alpha3.ProtocolHTTPS,
-		},
-		TLS: &v1alpha3.TLSOptions{
-			Mode:              v1alpha3.TLSModeSimple,
-			ServerCertificate: "tls.crt",
-			PrivateKey:        "tls.key",
-		},
+var servers = []*istiov1alpha3.Server{{
+	Hosts: []string{"host1.example.com"},
+	Port: &istiov1alpha3.Port{
+		Name:     "test-ns/ingress:0",
+		Number:   443,
+		Protocol: "HTTPS",
 	},
-}
+	Tls: &istiov1alpha3.Server_TLSOptions{
+		Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+		ServerCertificate: corev1.TLSCertKey,
+		PrivateKey:        corev1.TLSPrivateKeyKey,
+	},
+}, {
+	Hosts: []string{"host2.example.com"},
+	Port: &istiov1alpha3.Port{
+		Name:     "test-ns/non-ingress:0",
+		Number:   443,
+		Protocol: "HTTPS",
+	},
+	Tls: &istiov1alpha3.Server_TLSOptions{
+		Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+		ServerCertificate: corev1.TLSCertKey,
+		PrivateKey:        corev1.TLSPrivateKeyKey,
+	},
+}}
 
-var httpServer = v1alpha3.Server{
+var httpServer = istiov1alpha3.Server{
 	Hosts: []string{"*"},
-	Port: v1alpha3.Port{
+	Port: &istiov1alpha3.Port{
 		Name:     httpServerPortName,
 		Number:   80,
-		Protocol: v1alpha3.ProtocolHTTP,
+		Protocol: "HTTP",
 	},
 }
 
 var gatewayWithPlaceholderServer = v1alpha3.Gateway{
-	Spec: v1alpha3.GatewaySpec{
-		Servers: []v1alpha3.Server{placeholderServer},
+	Spec: istiov1alpha3.Gateway{
+		Servers: []*istiov1alpha3.Server{&placeholderServer},
 	},
 }
 
 var gatewayWithDefaultWildcardTLSServer = v1alpha3.Gateway{
-	Spec: v1alpha3.GatewaySpec{
-		Servers: []v1alpha3.Server{{
+	Spec: istiov1alpha3.Gateway{
+		Servers: []*istiov1alpha3.Server{{
 			Hosts: []string{"*"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "https",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode: v1alpha3.TLSModePassThrough,
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode: istiov1alpha3.Server_TLSOptions_SIMPLE,
 			}},
 		},
 	},
 }
 
 var gatewayWithModifiedWildcardTLSServer = v1alpha3.Gateway{
-	Spec: v1alpha3.GatewaySpec{
-		Servers: []v1alpha3.Server{modifiedDefaultTLSServer},
+	Spec: istiov1alpha3.Gateway{
+		Servers: []*istiov1alpha3.Server{&modifiedDefaultTLSServer},
 	},
 }
 
-var modifiedDefaultTLSServer = v1alpha3.Server{
+var modifiedDefaultTLSServer = istiov1alpha3.Server{
 	Hosts: []string{"added.by.user.example.com"},
-	Port: v1alpha3.Port{
+	Port: &istiov1alpha3.Port{
 		Name:     "https",
 		Number:   443,
-		Protocol: v1alpha3.ProtocolHTTPS,
+		Protocol: "HTTPS",
 	},
-	TLS: &v1alpha3.TLSOptions{
-		Mode:              v1alpha3.TLSModeSimple,
-		ServerCertificate: "tls.crt",
-		PrivateKey:        "tls.key",
+	Tls: &istiov1alpha3.Server_TLSOptions{
+		Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+		ServerCertificate: corev1.TLSCertKey,
+		PrivateKey:        corev1.TLSPrivateKeyKey,
 	},
 }
 
@@ -148,15 +147,13 @@ var ingressSpec = v1alpha1.IngressSpec{
 		Hosts: []string{"host1.example.com"},
 	}},
 	TLS: []v1alpha1.IngressTLS{{
-		Hosts:             []string{"host1.example.com"},
-		SecretName:        "secret0",
-		SecretNamespace:   system.Namespace(),
-		ServerCertificate: "tls.crt",
-		PrivateKey:        "tls.key",
+		Hosts:           []string{"host1.example.com"},
+		SecretName:      "secret0",
+		SecretNamespace: system.Namespace(),
 	}},
 }
 
-var ingress = v1alpha1.Ingress{
+var ingressResource = v1alpha1.Ingress{
 	ObjectMeta: metav1.ObjectMeta{
 		Name:      "ingress",
 		Namespace: "test-ns",
@@ -165,18 +162,18 @@ var ingress = v1alpha1.Ingress{
 }
 
 func TestGetServers(t *testing.T) {
-	servers := GetServers(&gateway, &ingress)
-	expected := []v1alpha3.Server{{
+	servers := GetServers(&gateway, &ingressResource)
+	expected := []*istiov1alpha3.Server{{
 		Hosts: []string{"host1.example.com"},
-		Port: v1alpha3.Port{
+		Port: &istiov1alpha3.Port{
 			Name:     "test-ns/ingress:0",
 			Number:   443,
-			Protocol: v1alpha3.ProtocolHTTPS,
+			Protocol: "HTTPS",
 		},
-		TLS: &v1alpha3.TLSOptions{
-			Mode:              v1alpha3.TLSModeSimple,
-			ServerCertificate: "tls.crt",
-			PrivateKey:        "tls.key",
+		Tls: &istiov1alpha3.Server_TLSOptions{
+			Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+			ServerCertificate: corev1.TLSCertKey,
+			PrivateKey:        corev1.TLSPrivateKeyKey,
 		},
 	}}
 
@@ -187,17 +184,17 @@ func TestGetServers(t *testing.T) {
 
 func TestGetHTTPServer(t *testing.T) {
 	newGateway := gateway
-	newGateway.Spec.Servers = append(newGateway.Spec.Servers, httpServer)
+	newGateway.Spec.Servers = append(newGateway.Spec.Servers, &httpServer)
 	server := GetHTTPServer(&newGateway)
-	expected := v1alpha3.Server{
+	expected := &istiov1alpha3.Server{
 		Hosts: []string{"*"},
-		Port: v1alpha3.Port{
+		Port: &istiov1alpha3.Port{
 			Name:     httpServerPortName,
 			Number:   80,
-			Protocol: v1alpha3.ProtocolHTTP,
+			Protocol: "HTTP",
 		},
 	}
-	if diff := cmp.Diff(expected, *server); diff != "" {
+	if diff := cmp.Diff(expected, server); diff != "" {
 		t.Errorf("Unexpected server (-want +got): %v", diff)
 	}
 }
@@ -205,74 +202,74 @@ func TestGetHTTPServer(t *testing.T) {
 func TestMakeTLSServers(t *testing.T) {
 	cases := []struct {
 		name                    string
-		ci                      v1alpha1.IngressAccessor
+		ci                      *v1alpha1.Ingress
 		gatewayServiceNamespace string
 		originSecrets           map[string]*corev1.Secret
-		expected                []v1alpha3.Server
+		expected                []*istiov1alpha3.Server
 		wantErr                 bool
 	}{{
 		name: "secret namespace is the different from the gateway service namespace",
-		ci:   &ingress,
+		ci:   &ingressResource,
 		// gateway service namespace is "istio-system", while the secret namespace is system.Namespace()("knative-testing").
 		gatewayServiceNamespace: "istio-system",
 		originSecrets:           originSecrets,
-		expected: []v1alpha3.Server{{
+		expected: []*istiov1alpha3.Server{{
 			Hosts: []string{"host1.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "test-ns/ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
-				CredentialName:    targetSecret(&secret, &ingress),
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
+				CredentialName:    targetSecret(&secret, &ingressResource),
 			},
 		}},
 	}, {
 		name: "secret namespace is the same as the gateway service namespace",
-		ci:   &ingress,
+		ci:   &ingressResource,
 		// gateway service namespace and the secret namespace are both in system.Namespace().
 		gatewayServiceNamespace: system.Namespace(),
 		originSecrets:           originSecrets,
-		expected: []v1alpha3.Server{{
+		expected: []*istiov1alpha3.Server{{
 			Hosts: []string{"host1.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "test-ns/ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 				CredentialName:    "secret0",
 			},
 		}},
 	}, {
 		name:                    "port name is created with ingress namespace-name",
-		ci:                      &ingress,
+		ci:                      &ingressResource,
 		gatewayServiceNamespace: system.Namespace(),
 		originSecrets:           originSecrets,
-		expected: []v1alpha3.Server{{
+		expected: []*istiov1alpha3.Server{{
 			Hosts: []string{"host1.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				// port name is created with <namespace>/<name>
 				Name:     "test-ns/ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 				CredentialName:    "secret0",
 			},
 		}},
 	}, {
 		name:                    "error to make servers because of incorrect originSecrets",
-		ci:                      &ingress,
+		ci:                      &ingressResource,
 		gatewayServiceNamespace: "istio-system",
 		originSecrets:           map[string]*corev1.Secret{},
 		wantErr:                 true,
@@ -294,7 +291,7 @@ func TestMakeHTTPServer(t *testing.T) {
 	cases := []struct {
 		name         string
 		httpProtocol network.HTTPProtocol
-		expected     *v1alpha3.Server
+		expected     *istiov1alpha3.Server
 	}{{
 		name:         "nil HTTP Server",
 		httpProtocol: network.HTTPDisabled,
@@ -302,9 +299,9 @@ func TestMakeHTTPServer(t *testing.T) {
 	}, {
 		name:         "HTTP server",
 		httpProtocol: network.HTTPEnabled,
-		expected: &v1alpha3.Server{
+		expected: &istiov1alpha3.Server{
 			Hosts: []string{"*"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     httpServerPortName,
 				Number:   80,
 				Protocol: "HTTP",
@@ -313,15 +310,15 @@ func TestMakeHTTPServer(t *testing.T) {
 	}, {
 		name:         "Redirect HTTP server",
 		httpProtocol: network.HTTPRedirected,
-		expected: &v1alpha3.Server{
+		expected: &istiov1alpha3.Server{
 			Hosts: []string{"*"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     httpServerPortName,
 				Number:   80,
 				Protocol: "HTTP",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				HTTPSRedirect: true,
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				HttpsRedirect: true,
 			},
 		},
 	}}
@@ -338,100 +335,100 @@ func TestMakeHTTPServer(t *testing.T) {
 func TestUpdateGateway(t *testing.T) {
 	cases := []struct {
 		name            string
-		existingServers []v1alpha3.Server
-		newServers      []v1alpha3.Server
+		existingServers []*istiov1alpha3.Server
+		newServers      []*istiov1alpha3.Server
 		original        v1alpha3.Gateway
 		expected        v1alpha3.Gateway
 	}{{
 		name: "Update Gateway servers.",
-		existingServers: []v1alpha3.Server{{
+		existingServers: []*istiov1alpha3.Server{{
 			Hosts: []string{"host1.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "test-ns/ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 			},
 		}},
-		newServers: []v1alpha3.Server{{
+		newServers: []*istiov1alpha3.Server{{
 			Hosts: []string{"host-new.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "test-ns/ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 			},
 		}},
 		original: gateway,
 		expected: v1alpha3.Gateway{
-			Spec: v1alpha3.GatewaySpec{
-				Servers: []v1alpha3.Server{{
+			Spec: istiov1alpha3.Gateway{
+				Servers: []*istiov1alpha3.Server{{
 					// The host name was updated to the one in "newServers".
 					Hosts: []string{"host-new.example.com"},
-					Port: v1alpha3.Port{
+					Port: &istiov1alpha3.Port{
 						Name:     "test-ns/ingress:0",
 						Number:   443,
-						Protocol: v1alpha3.ProtocolHTTPS,
+						Protocol: "HTTPS",
 					},
-					TLS: &v1alpha3.TLSOptions{
-						Mode:              v1alpha3.TLSModeSimple,
-						ServerCertificate: "tls.crt",
-						PrivateKey:        "tls.key",
+					Tls: &istiov1alpha3.Server_TLSOptions{
+						Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+						ServerCertificate: corev1.TLSCertKey,
+						PrivateKey:        corev1.TLSPrivateKeyKey,
 					},
 				}, {
 					Hosts: []string{"host2.example.com"},
-					Port: v1alpha3.Port{
+					Port: &istiov1alpha3.Port{
 						Name:     "test-ns/non-ingress:0",
 						Number:   443,
-						Protocol: v1alpha3.ProtocolHTTPS,
+						Protocol: "HTTPS",
 					},
-					TLS: &v1alpha3.TLSOptions{
-						Mode:              v1alpha3.TLSModeSimple,
-						ServerCertificate: "tls.crt",
-						PrivateKey:        "tls.key",
+					Tls: &istiov1alpha3.Server_TLSOptions{
+						Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+						ServerCertificate: corev1.TLSCertKey,
+						PrivateKey:        corev1.TLSPrivateKeyKey,
 					},
 				}},
 			},
 		},
 	}, {
 		name: "Delete servers from Gateway",
-		existingServers: []v1alpha3.Server{{
+		existingServers: []*istiov1alpha3.Server{{
 			Hosts: []string{"host1.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "test-ns/ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 			},
 		}},
-		newServers: []v1alpha3.Server{},
+		newServers: []*istiov1alpha3.Server{},
 		original:   gateway,
 		expected: v1alpha3.Gateway{
-			Spec: v1alpha3.GatewaySpec{
+			Spec: istiov1alpha3.Gateway{
 				// Only one server is left. The other one is deleted.
-				Servers: []v1alpha3.Server{{
+				Servers: []*istiov1alpha3.Server{{
 					Hosts: []string{"host2.example.com"},
-					Port: v1alpha3.Port{
+					Port: &istiov1alpha3.Port{
 						Name:     "test-ns/non-ingress:0",
 						Number:   443,
-						Protocol: v1alpha3.ProtocolHTTPS,
+						Protocol: "HTTPS",
 					},
-					TLS: &v1alpha3.TLSOptions{
-						Mode:              v1alpha3.TLSModeSimple,
-						ServerCertificate: "tls.crt",
-						PrivateKey:        "tls.key",
+					Tls: &istiov1alpha3.Server_TLSOptions{
+						Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+						ServerCertificate: corev1.TLSCertKey,
+						PrivateKey:        corev1.TLSPrivateKeyKey,
 					},
 				}},
 			},
@@ -440,110 +437,110 @@ func TestUpdateGateway(t *testing.T) {
 		name: "Delete servers from Gateway and no real servers are left",
 
 		// All of the servers in the original gateway will be deleted.
-		existingServers: []v1alpha3.Server{{
+		existingServers: []*istiov1alpha3.Server{{
 			Hosts: []string{"host1.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "test-ns/ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 			},
 		}, {
 			Hosts: []string{"host2.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "test-ns/non-ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 			},
 		}},
-		newServers: []v1alpha3.Server{},
+		newServers: []*istiov1alpha3.Server{},
 		original:   gateway,
 		expected:   gatewayWithPlaceholderServer,
 	}, {
 		name:            "Add servers to the gateway with only placeholder server",
-		existingServers: []v1alpha3.Server{},
-		newServers: []v1alpha3.Server{{
+		existingServers: []*istiov1alpha3.Server{},
+		newServers: []*istiov1alpha3.Server{{
 			Hosts: []string{"host1.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "test-ns/ingress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 			},
 		}},
 		original: gatewayWithPlaceholderServer,
 		// The placeholder server should be deleted.
 		expected: v1alpha3.Gateway{
-			Spec: v1alpha3.GatewaySpec{
-				Servers: []v1alpha3.Server{{
+			Spec: istiov1alpha3.Gateway{
+				Servers: []*istiov1alpha3.Server{{
 					Hosts: []string{"host1.example.com"},
-					Port: v1alpha3.Port{
+					Port: &istiov1alpha3.Port{
 						Name:     "test-ns/ingress:0",
 						Number:   443,
-						Protocol: v1alpha3.ProtocolHTTPS,
+						Protocol: "HTTPS",
 					},
-					TLS: &v1alpha3.TLSOptions{
-						Mode:              v1alpha3.TLSModeSimple,
-						ServerCertificate: "tls.crt",
-						PrivateKey:        "tls.key",
+					Tls: &istiov1alpha3.Server_TLSOptions{
+						Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+						ServerCertificate: corev1.TLSCertKey,
+						PrivateKey:        corev1.TLSPrivateKeyKey,
 					},
 				}},
 			},
 		},
 	}, {
 		name:            "Delete wildcard servers from gateway",
-		existingServers: []v1alpha3.Server{},
+		existingServers: []*istiov1alpha3.Server{},
 		newServers:      servers,
 		original:        gatewayWithDefaultWildcardTLSServer,
 		// The wildcard server should be deleted.
 		expected: gateway,
 	}, {
 		name:            "Do not delete modified wildcard servers from gateway",
-		existingServers: []v1alpha3.Server{},
-		newServers: []v1alpha3.Server{{
+		existingServers: []*istiov1alpha3.Server{},
+		newServers: []*istiov1alpha3.Server{{
 			Hosts: []string{"host1.example.com"},
-			Port: v1alpha3.Port{
+			Port: &istiov1alpha3.Port{
 				Name:     "clusteringress:0",
 				Number:   443,
-				Protocol: v1alpha3.ProtocolHTTPS,
+				Protocol: "HTTPS",
 			},
-			TLS: &v1alpha3.TLSOptions{
-				Mode:              v1alpha3.TLSModeSimple,
-				ServerCertificate: "tls.crt",
-				PrivateKey:        "tls.key",
+			Tls: &istiov1alpha3.Server_TLSOptions{
+				Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+				ServerCertificate: corev1.TLSCertKey,
+				PrivateKey:        corev1.TLSPrivateKeyKey,
 			},
 		}},
 		original: gatewayWithModifiedWildcardTLSServer,
 		expected: v1alpha3.Gateway{
-			Spec: v1alpha3.GatewaySpec{
-				Servers: []v1alpha3.Server{
+			Spec: istiov1alpha3.Gateway{
+				Servers: []*istiov1alpha3.Server{
 					{
 						Hosts: []string{"host1.example.com"},
-						Port: v1alpha3.Port{
+						Port: &istiov1alpha3.Port{
 							Name:     "clusteringress:0",
 							Number:   443,
-							Protocol: v1alpha3.ProtocolHTTPS,
+							Protocol: "HTTPS",
 						},
-						TLS: &v1alpha3.TLSOptions{
-							Mode:              v1alpha3.TLSModeSimple,
-							ServerCertificate: "tls.crt",
-							PrivateKey:        "tls.key",
+						Tls: &istiov1alpha3.Server_TLSOptions{
+							Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+							ServerCertificate: corev1.TLSCertKey,
+							PrivateKey:        corev1.TLSPrivateKeyKey,
 						},
 					},
-					modifiedDefaultTLSServer,
+					&modifiedDefaultTLSServer,
 				},
 			},
 		},
@@ -562,14 +559,14 @@ func TestUpdateGateway(t *testing.T) {
 func TestMakeIngressGateways(t *testing.T) {
 	cases := []struct {
 		name           string
-		ia             v1alpha1.IngressAccessor
+		ia             *v1alpha1.Ingress
 		originSecrets  map[string]*corev1.Secret
 		gatewayService *corev1.Service
 		want           []*v1alpha3.Gateway
 		wantErr        bool
 	}{{
 		name:          "happy path: secret namespace is the different from the gateway service namespace",
-		ia:            &ingress,
+		ia:            &ingressResource,
 		originSecrets: originSecrets,
 		gatewayService: &corev1.Service{
 			ObjectMeta: metav1.ObjectMeta{
@@ -584,29 +581,29 @@ func TestMakeIngressGateways(t *testing.T) {
 			ObjectMeta: metav1.ObjectMeta{
 				Name:            fmt.Sprintf("ingress-%d", adler32.Checksum([]byte("istio-system/istio-ingressgateway"))),
 				Namespace:       "test-ns",
-				OwnerReferences: []metav1.OwnerReference{*kmeta.NewControllerRef(&ingress)},
+				OwnerReferences: []metav1.OwnerReference{*kmeta.NewControllerRef(&ingressResource)},
 				Labels: map[string]string{
 					networking.IngressLabelKey: "ingress",
 				},
 			},
-			Spec: v1alpha3.GatewaySpec{
+			Spec: istiov1alpha3.Gateway{
 				Selector: selector,
-				Servers: []v1alpha3.Server{{
+				Servers: []*istiov1alpha3.Server{{
 					Hosts: []string{"host1.example.com"},
-					Port: v1alpha3.Port{
+					Port: &istiov1alpha3.Port{
 						Name:     "test-ns/ingress:0",
 						Number:   443,
-						Protocol: v1alpha3.ProtocolHTTPS,
+						Protocol: "HTTPS",
 					},
-					TLS: &v1alpha3.TLSOptions{
-						Mode:              v1alpha3.TLSModeSimple,
-						ServerCertificate: "tls.crt",
-						PrivateKey:        "tls.key",
-						CredentialName:    targetSecret(&secret, &ingress),
+					Tls: &istiov1alpha3.Server_TLSOptions{
+						Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+						ServerCertificate: corev1.TLSCertKey,
+						PrivateKey:        corev1.TLSPrivateKeyKey,
+						CredentialName:    targetSecret(&secret, &ingressResource),
 					},
 				}, {
 					Hosts: []string{"host1.example.com"},
-					Port: v1alpha3.Port{
+					Port: &istiov1alpha3.Port{
 						Name:     httpServerPortName,
 						Number:   80,
 						Protocol: "HTTP",
@@ -616,7 +613,7 @@ func TestMakeIngressGateways(t *testing.T) {
 		}},
 	}, {
 		name:          "happy path: secret namespace is the same as the gateway service namespace",
-		ia:            &ingress,
+		ia:            &ingressResource,
 		originSecrets: originSecrets,
 		// The namespace of gateway service is the same as the secrets.
 		gatewayService: &corev1.Service{
@@ -632,29 +629,29 @@ func TestMakeIngressGateways(t *testing.T) {
 			ObjectMeta: metav1.ObjectMeta{
 				Name:            fmt.Sprintf("ingress-%d", adler32.Checksum([]byte(system.Namespace()+"/istio-ingressgateway"))),
 				Namespace:       "test-ns",
-				OwnerReferences: []metav1.OwnerReference{*kmeta.NewControllerRef(&ingress)},
+				OwnerReferences: []metav1.OwnerReference{*kmeta.NewControllerRef(&ingressResource)},
 				Labels: map[string]string{
 					networking.IngressLabelKey: "ingress",
 				},
 			},
-			Spec: v1alpha3.GatewaySpec{
+			Spec: istiov1alpha3.Gateway{
 				Selector: selector,
-				Servers: []v1alpha3.Server{{
+				Servers: []*istiov1alpha3.Server{{
 					Hosts: []string{"host1.example.com"},
-					Port: v1alpha3.Port{
+					Port: &istiov1alpha3.Port{
 						Name:     "test-ns/ingress:0",
 						Number:   443,
-						Protocol: v1alpha3.ProtocolHTTPS,
+						Protocol: "HTTPS",
 					},
-					TLS: &v1alpha3.TLSOptions{
-						Mode:              v1alpha3.TLSModeSimple,
-						ServerCertificate: "tls.crt",
-						PrivateKey:        "tls.key",
+					Tls: &istiov1alpha3.Server_TLSOptions{
+						Mode:              istiov1alpha3.Server_TLSOptions_SIMPLE,
+						ServerCertificate: corev1.TLSCertKey,
+						PrivateKey:        corev1.TLSPrivateKeyKey,
 						CredentialName:    secret.Name,
 					},
 				}, {
 					Hosts: []string{"host1.example.com"},
-					Port: v1alpha3.Port{
+					Port: &istiov1alpha3.Port{
 						Name:     httpServerPortName,
 						Number:   80,
 						Protocol: "HTTP",
@@ -664,7 +661,7 @@ func TestMakeIngressGateways(t *testing.T) {
 		}},
 	}, {
 		name:          "error to make gateway because of incorrect originSecrets",
-		ia:            &ingress,
+		ia:            &ingressResource,
 		originSecrets: map[string]*corev1.Secret{},
 		gatewayService: &corev1.Service{
 			ObjectMeta: metav1.ObjectMeta{
@@ -685,7 +682,7 @@ func TestMakeIngressGateways(t *testing.T) {
 		ctx = config.ToContext(context.Background(), &config.Config{
 			Istio: &config.Istio{
 				IngressGateways: []config.Gateway{{
-					Name:       "knative-ingress-gateway",
+					Name:       networking.KnativeIngressGateway,
 					ServiceURL: fmt.Sprintf("%s.%s.svc.cluster.local", c.gatewayService.Name, c.gatewayService.Namespace),
 				}},
 			},
