@@ -20,24 +20,23 @@ import (
 	"context"
 	"fmt"
 	"testing"
+	"time"
 
 	"github.com/google/go-cmp/cmp"
-	"github.com/google/go-cmp/cmp/cmpopts"
 	"golang.org/x/sync/errgroup"
 
 	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	clientgotesting "k8s.io/client-go/testing"
+	"k8s.io/client-go/tools/cache"
 
-	fakeinformerfactory "knative.dev/pkg/client/injection/kube/informers/factory"
 	"knative.dev/pkg/configmap"
 	"knative.dev/pkg/controller"
 	. "knative.dev/pkg/reconciler/testing"
 	"knative.dev/pkg/system"
 	"knative.dev/serving/pkg/apis/networking"
 	"knative.dev/serving/pkg/apis/networking/v1alpha1"
-	fakeservingclient "knative.dev/serving/pkg/client/injection/client/fake"
 	"knative.dev/serving/pkg/network"
 	pkgreconciler "knative.dev/serving/pkg/reconciler"
 	"knative.dev/serving/pkg/reconciler/nscert/config"
@@ -45,9 +44,12 @@ import (
 	routecfg "knative.dev/serving/pkg/reconciler/route/config"
 	. "knative.dev/serving/pkg/reconciler/testing/v1alpha1"
 
-	_ "knative.dev/pkg/client/injection/kube/informers/core/v1/namespace/fake"
-	_ "knative.dev/pkg/system/testing"
+	fakekubeclient "knative.dev/pkg/client/injection/kube/client/fake"
+	fakensinformer "knative.dev/pkg/client/injection/kube/informers/core/v1/namespace/fake"
+	fakeservingclient "knative.dev/serving/pkg/client/injection/client/fake"
 	fakecertinformer "knative.dev/serving/pkg/client/injection/informers/networking/v1alpha1/certificate/fake"
+
+	_ "knative.dev/pkg/system/testing"
 )
 
 var (
@@ -58,8 +60,7 @@ var (
 )
 
 func newTestSetup(t *testing.T, configs ...*corev1.ConfigMap) (
-	context.Context, context.CancelFunc,
-	*controller.Impl, *configmap.ManualWatcher) {
+	context.Context, context.CancelFunc, chan *v1alpha1.Certificate, *configmap.ManualWatcher) {
 	t.Helper()
 
 	ctx, ccl, ifs := SetupFakeContextWithCancel(t)
@@ -74,7 +75,7 @@ func newTestSetup(t *testing.T, configs ...*corev1.ConfigMap) (
 
 	configMapWatcher := &configmap.ManualWatcher{Namespace: system.Namespace()}
 
-	controller := NewController(ctx, configMapWatcher)
+	ctl := NewController(ctx, configMapWatcher)
 
 	cms := []*corev1.ConfigMap{{
 		ObjectMeta: metav1.ObjectMeta{
@@ -99,13 +100,24 @@ func newTestSetup(t *testing.T, configs ...*corev1.ConfigMap) (
 	for _, cfg := range cms {
 		configMapWatcher.OnChange(cfg)
 	}
+	if err := configMapWatcher.Start(ctx.Done()); err != nil {
+		t.Fatalf("failed to start config manager: %v", err)
+	}
+
+	certEvents := make(chan *v1alpha1.Certificate)
+	fakecertinformer.Get(ctx).Informer().AddEventHandler(cache.FilteringResourceEventHandler{
+		FilterFunc: controller.Filter(corev1.SchemeGroupVersion.WithKind("Namespace")),
+		Handler: controller.HandleAll(func(obj interface{}) {
+			certEvents <- obj.(*v1alpha1.Certificate)
+		}),
+	})
 
 	var eg errgroup.Group
-	eg.Go(func() error { return controller.Run(2, ctx.Done()) })
+	eg.Go(func() error { return ctl.Run(1, ctx.Done()) })
 	return ctx, func() {
 		cancel()
 		eg.Wait()
-	}, controller, configMapWatcher
+	}, certEvents, configMapWatcher
 }
 
 func TestNewController(t *testing.T) {
@@ -208,32 +220,16 @@ func TestUpdateDomainTemplate(t *testing.T) {
 			"autoTLS": "Enabled",
 		},
 	}
-	ctx, cancel, controller, watcher := newTestSetup(t, netCfg)
+	ctx, cancel, certEvents, watcher := newTestSetup(t, netCfg)
 	defer cancel()
-	reconciler := controller.Reconciler.(*reconciler)
 
-	sorter := cmpopts.SortSlices(func(a, b string) bool {
-		return a < b
-	})
-	// Create a namespace and wildcard cert using the default domain template
-	ns := kubeNamespace("testns")
-	nsInformer := fakeinformerfactory.Get(ctx).Core().V1().Namespaces()
-	knCertificateInformer := fakecertinformer.Get(ctx)
+	namespace := kubeNamespace("testns")
+	fakekubeclient.Get(ctx).CoreV1().Namespaces().Create(namespace)
+	fakensinformer.Get(ctx).Informer().GetIndexer().Add(namespace)
 
-	expected := []string{fmt.Sprintf("*.%s.%s", ns.Name, routecfg.DefaultDomain)}
-
-	nsInformer.Informer().GetIndexer().Add(ns)
-	reconciler.Reconcile(context.Background(), ns.Name)
-	selector := fmt.Sprintf("%s=%s", networking.WildcardCertDomainLabelKey, routecfg.DefaultDomain)
-	certs, _ := fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates(ns.Name).List(metav1.ListOptions{
-		LabelSelector: selector,
-	})
-	cert := certs.Items[0]
-	knCertificateInformer.Informer().GetIndexer().Add(&cert)
-
-	actual := cert.Spec.DNSNames
-
-	if diff := cmp.Diff(expected, actual); diff != "" {
+	want := []string{fmt.Sprintf("*.%s.%s", namespace.Name, routecfg.DefaultDomain)}
+	cert := <-certEvents
+	if diff := cmp.Diff(want, cert.Spec.DNSNames); diff != "" {
 		t.Errorf("DNSNames (-want, +got) = %s", diff)
 	}
 
@@ -249,15 +245,12 @@ func TestUpdateDomainTemplate(t *testing.T) {
 		},
 	}
 	watcher.OnChange(netCfg)
-	reconciler.Reconcile(context.Background(), ns.Name)
-	certs, _ = fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates(ns.Name).List(metav1.ListOptions{
-		LabelSelector: selector,
-	})
-	actual = certs.Items[0].Spec.DNSNames
 
-	// Since no new names should be added our expected value hasn't changed
-	if diff := cmp.Diff(expected, actual); diff != "" {
-		t.Errorf("DNSNames (-want, +got) = %s", diff)
+	// Since no new names should be added nothing should change
+	select {
+	case <-certEvents:
+		t.Error("Unexpected event")
+	case <-time.After(100 * time.Millisecond):
 	}
 
 	// Update the domain template to something not matched by the existing DNSName
@@ -272,18 +265,14 @@ func TestUpdateDomainTemplate(t *testing.T) {
 		},
 	}
 	watcher.OnChange(netCfg)
-	reconciler.Reconcile(context.Background(), ns.Name)
-
-	expected = []string{fmt.Sprintf("*.subdomain.%s.%s", ns.Name, routecfg.DefaultDomain)}
-	certs, _ = fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates(ns.Name).List(metav1.ListOptions{
-		LabelSelector: selector,
-	})
-	actual = certs.Items[0].Spec.DNSNames
 
 	// A new domain format not matched by the existing certificate should update the DNSName
-	if diff := cmp.Diff(expected, actual, sorter); diff != "" {
+	want = []string{fmt.Sprintf("*.subdomain.%s.%s", namespace.Name, routecfg.DefaultDomain)}
+	cert = <-certEvents
+	if diff := cmp.Diff(want, cert.Spec.DNSNames); diff != "" {
 		t.Errorf("DNSNames (-want, +got) = %s", diff)
 	}
+
 	// Invalid domain template for wildcard certs
 	netCfg = &corev1.ConfigMap{
 		ObjectMeta: metav1.ObjectMeta{
@@ -296,16 +285,12 @@ func TestUpdateDomainTemplate(t *testing.T) {
 		},
 	}
 	watcher.OnChange(netCfg)
-	reconciler.Reconcile(context.Background(), ns.Name)
 
-	certs, _ = fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates(ns.Name).List(metav1.ListOptions{
-		LabelSelector: selector,
-	})
-	actual = certs.Items[0].Spec.DNSNames
-
-	// With an invalid domain template nothing should have changed
-	if diff := cmp.Diff(expected, actual, sorter); diff != "" {
-		t.Errorf("DNSNames (-want, +got) = %s", diff)
+	// With an invalid domain template nothing change
+	select {
+	case <-certEvents:
+		t.Error("Unexpected event")
+	case <-time.After(100 * time.Millisecond):
 	}
 }
 
@@ -328,26 +313,16 @@ func TestDomainConfigDefaultDomain(t *testing.T) {
 			"autoTLS": "Enabled",
 		},
 	}
-	ctx, cancel, controller, _ := newTestSetup(t, domCfg, netCfg)
+	ctx, cancel, certEvents, _ := newTestSetup(t, domCfg, netCfg)
 	defer cancel()
-	reconciler := controller.Reconciler.(*reconciler)
 
-	ns := kubeNamespace("testns")
-	nsInformer := fakeinformerfactory.Get(ctx).Core().V1().Namespaces()
-	knCertificateInformer := fakecertinformer.Get(ctx)
+	namespace := kubeNamespace("testns")
+	fakekubeclient.Get(ctx).CoreV1().Namespaces().Create(namespace)
+	fakensinformer.Get(ctx).Informer().GetIndexer().Add(namespace)
 
-	nsInformer.Informer().GetIndexer().Add(ns)
-	reconciler.Reconcile(context.Background(), ns.Name)
-	certName := "testns.example.com"
-	expectedDomain := "*.testns.example.com"
-
-	cert, _ := fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates(ns.Name).Get(certName, metav1.GetOptions{})
-	knCertificateInformer.Informer().GetIndexer().Add(cert)
-
-	actualDomain := cert.Spec.DNSNames[0]
-
-	if actualDomain != expectedDomain {
-		t.Errorf("Expected certificate to be issued for %s but got it was issued for %s", expectedDomain, actualDomain)
+	cert := <-certEvents
+	if got, want := cert.Spec.DNSNames[0], "*.testns.example.com"; got != want {
+		t.Errorf("DNSName[0] = %s, want %s", got, want)
 	}
 }
 
@@ -362,20 +337,20 @@ func TestChangeDefaultDomain(t *testing.T) {
 		},
 	}
 
-	ctx, cancel, controller, watcher := newTestSetup(t, netCfg)
-	defer func() {
-		cancel()
-	}()
-	reconciler := controller.Reconciler.(*reconciler)
-	ns := kubeNamespace("testns")
-	nsInformer := fakeinformerfactory.Get(ctx).Core().V1().Namespaces()
-	nsInformer.Informer().GetIndexer().Add(ns)
-	reconciler.Reconcile(context.Background(), "testns")
+	ctx, cancel, certEvents, watcher := newTestSetup(t, netCfg)
+	defer cancel()
 
-	cert, _ := fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates(ns.Name).Get("testns.example.com", metav1.GetOptions{})
-	knCertificateInformer := fakecertinformer.Get(ctx)
-	knCertificateInformer.Informer().GetIndexer().Add(cert)
+	namespace := kubeNamespace("testns")
+	fakekubeclient.Get(ctx).CoreV1().Namespaces().Create(namespace)
+	fakensinformer.Get(ctx).Informer().GetIndexer().Add(namespace)
 
+	// The certificate should be created with the default domain.
+	cert := <-certEvents
+	if got, want := cert.Spec.DNSNames[0], "*.testns.example.com"; got != want {
+		t.Errorf("DNSName[0] = %s, want %s", got, want)
+	}
+
+	// Change the domain settings.
 	domCfg := &corev1.ConfigMap{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      routecfg.DomainConfigName,
@@ -386,17 +361,17 @@ func TestChangeDefaultDomain(t *testing.T) {
 		},
 	}
 	watcher.OnChange(domCfg)
-	reconciler.Reconcile(context.Background(), ns.Name)
 
-	certs, _ := fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates(ns.Name).List(metav1.ListOptions{})
-	if len(certs.Items) > 1 {
-		t.Errorf("Expected 1 certificate, got %d.", len(certs.Items))
+	// The certificate should be updated with the new domain.
+	cert2 := <-certEvents
+	if got, want := cert2.Spec.DNSNames[0], "*.testns.example.net"; got != want {
+		t.Errorf("DNSName[0] = %s, want %s", got, want)
 	}
 
-	actualDomain := certs.Items[0].Spec.DNSNames[0]
-	expectedDomain := "*.testns.example.net"
-	if actualDomain != expectedDomain {
-		t.Errorf("Expected certificate to be issued for %s but it was issued for %s", expectedDomain, actualDomain)
+	// Assert we have exactly one certificate.
+	certs, _ := fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates(namespace.Name).List(metav1.ListOptions{})
+	if len(certs.Items) > 1 {
+		t.Errorf("Expected 1 certificate, got %d.", len(certs.Items))
 	}
 }
 
@@ -419,20 +394,16 @@ func TestDomainConfigExplicitDefaultDomain(t *testing.T) {
 			"autoTLS": "Enabled",
 		},
 	}
-	ctx, cancel, controller, _ := newTestSetup(t, domCfg, netCfg)
+	ctx, cancel, certEvents, _ := newTestSetup(t, domCfg, netCfg)
 	defer cancel()
-	reconciler := controller.Reconciler.(*reconciler)
+
 	namespace := kubeNamespace("testns")
-	nsInformer := fakeinformerfactory.Get(ctx).Core().V1().Namespaces()
-	nsInformer.Informer().GetIndexer().Add(namespace)
-	reconciler.Reconcile(context.Background(), "testns")
-	certs, _ := fakeservingclient.Get(ctx).NetworkingV1alpha1().Certificates("testns").List(metav1.ListOptions{})
+	fakekubeclient.Get(ctx).CoreV1().Namespaces().Create(namespace)
+	fakensinformer.Get(ctx).Informer().GetIndexer().Add(namespace)
 
-	expectedDomain := "*.testns.default.com"
-	actualDomain := certs.Items[0].Spec.DNSNames[0]
-
-	if actualDomain != expectedDomain {
-		t.Errorf("Expected certificate to be issued for %s but got it was issued for %s", expectedDomain, actualDomain)
+	cert := <-certEvents
+	if got, want := cert.Spec.DNSNames[0], "*.testns.default.com"; got != want {
+		t.Errorf("DNSName[0] = %s, want %s", got, want)
 	}
 }
 
