@@ -25,32 +25,30 @@ E2E_CLUSTER_MACHINE=${E2E_CLUSTER_MACHINE:-n1-standard-8}
 # This script provides helper methods to perform cluster actions.
 source $(dirname $0)/../vendor/knative.dev/test-infra/scripts/e2e-tests.sh
 
-CERT_MANAGER_VERSION="0.9.1"
+CERT_MANAGER_VERSION="0.12.0"
 ISTIO_VERSION=""
 GLOO_VERSION=""
 KOURIER_VERSION=""
+AMBASSADOR_VERSION=""
+CONTOUR_VERSION=""
+INGRESS_CLASS=""
 
 HTTPS=0
-
-# Current YAMLs used to install Knative Serving.
-INSTALL_RELEASE_YAML=""
-INSTALL_MONITORING_YAML=""
-
+MESH=0
 INSTALL_MONITORING=0
 
-GATEWAY_SETUP=0
-RECONCILE_GATEWAY=0
-
 # List of custom YAMLs to install, if specified (space-separated).
 INSTALL_CUSTOM_YAMLS=""
 
+UNINSTALL_LIST=()
+
 # Parse our custom flags.
 function parse_flags() {
   case "$1" in
     --istio-version)
       [[ $2 =~ ^[0-9]+\.[0-9]+(\.[0-9]+|\-latest)$ ]] || abort "version format must be '[0-9].[0-9].[0-9]' or '[0-9].[0-9]-latest"
       readonly ISTIO_VERSION=$2
-      GATEWAY_SETUP=1
+      readonly INGRESS_CLASS="istio.ingress.networking.knative.dev"
       return 2
       ;;
     --version)
@@ -79,10 +77,6 @@ function parse_flags() {
       readonly INSTALL_MONITORING=1
       return 1
       ;;
-    --reconcile-gateway)
-      readonly RECONCILE_GATEWAY=1
-      return 1
-      ;;
     --custom-yamls)
       [[ -z "$2" ]] && fail_test "Missing argument to --custom-yamls"
       # Expect a list of comma-separated YAMLs.
@@ -94,14 +88,28 @@ function parse_flags() {
       # currently, the value of --gloo-version is ignored
       # latest version of Gloo pinned in third_party will be installed
       readonly GLOO_VERSION=$2
-      GATEWAY_SETUP=1
+      readonly INGRESS_CLASS="gloo.ingress.networking.knative.dev"
       return 2
       ;;
     --kourier-version)
       # currently, the value of --kourier-version is ignored
       # latest version of Kourier pinned in third_party will be installed
       readonly KOURIER_VERSION=$2
-      GATEWAY_SETUP=1
+      readonly INGRESS_CLASS="kourier.ingress.networking.knative.dev"
+      return 2
+      ;;
+    --ambassador-version)
+      # currently, the value of --ambassador-version is ignored
+      # latest version of Ambassador pinned in third_party will be installed
+      readonly AMBASSADOR_VERSION=$2
+      readonly INGRESS_CLASS="ambassador.ingress.networking.knative.dev"
+      return 2
+      ;;
+    --contour-version)
+      # currently, the value of --contour-version is ignored
+      # latest version of Contour pinned in third_party will be installed
+      readonly CONTOUR_VERSION=$2
+      readonly INGRESS_CLASS="contour.ingress.networking.knative.dev"
       return 2
       ;;
   esac
@@ -115,11 +123,6 @@ function parse_flags() {
 function build_knative_from_source() {
   local YAML_LIST="$(mktemp)"
 
-  # Set ko flags to omit istio resources from generated YAMLs
-  if [[ -z "${ISTIO_VERSION}" ]]; then
-    KO_FLAGS="${KO_FLAGS} --selector=networking.knative.dev/ingress-provider!=istio"
-  fi
-
   # Generate manifests, capture environment variables pointing to the YAML files.
   local FULL_OUTPUT="$( \
       source $(dirname $0)/../hack/generate-yamls.sh ${REPO_ROOT_DIR} ${YAML_LIST} ; \
@@ -152,9 +155,19 @@ function install_knative_serving() {
 }
 
 function install_istio() {
+  # If no gateway was set on command line, assume Istio
+  if [[ -z "${ISTIO_VERSION}" ]]; then
+    echo ">> No gateway set up on command line, using Istio"
+    readonly ISTIO_VERSION="1.4-latest"
+  fi
+
   local istio_base="./third_party/istio-${ISTIO_VERSION}"
   INSTALL_ISTIO_CRD_YAML="${istio_base}/istio-crds.yaml"
-  (( MESH )) && INSTALL_ISTIO_YAML="${istio_base}/istio.yaml" || INSTALL_ISTIO_YAML="${istio_base}/istio-lean.yaml"
+  if (( MESH )); then
+    INSTALL_ISTIO_YAML="${istio_base}/istio-ci-mesh.yaml"
+  else
+    INSTALL_ISTIO_YAML="${istio_base}/istio-ci-no-mesh.yaml"
+  fi
 
   echo "Istio CRD YAML: ${INSTALL_ISTIO_CRD_YAML}"
   echo "Istio YAML: ${INSTALL_ISTIO_YAML}"
@@ -163,32 +176,91 @@ function install_istio() {
   echo ">> Running Istio CRD installer"
   kubectl apply -f "${INSTALL_ISTIO_CRD_YAML}" || return 1
   wait_until_batch_job_complete istio-system || return 1
-
-  echo ">> Bringing up Istio"
-  echo ">> Running Istio CRD installer"
-  kubectl apply -f "${INSTALL_ISTIO_CRD_YAML}" || return 1
-  wait_until_batch_job_complete istio-system || return 1
+  UNINSTALL_LIST+=( "${INSTALL_ISTIO_CRD_YAML}" )
 
   echo ">> Running Istio"
   kubectl apply -f "${INSTALL_ISTIO_YAML}" || return 1
+  UNINSTALL_LIST+=( "${INSTALL_ISTIO_YAML}" )
+
+  echo ">> Patching Istio"
+  # There are reports of Envoy failing (503) when istio-pilot is overloaded.
+  # We generously add more pilot instances here to reduce flakes.
+  if kubectl get hpa -n istio-system istio-pilot 2>/dev/null; then
+    kubectl patch hpa -n istio-system istio-pilot \
+            --patch '{"spec": {"minReplicas": 3, "maxReplicas": 10, "targetCPUUtilizationPercentage": 60}}' || return 1
+  else
+    # Some versions of Istio don't provide an HPA for pilot.
+    kubectl autoscale -n istio-system deploy istio-pilot --min=3 --max=10 --cpu-percent=60 || return 1
+  fi
+
+  # If the yaml for the Istio Ingress controller is passed, then install it.
+  if [[ -n "$1" ]]; then
+    echo ">> Installing Istio Ingress"
+    echo "Istio Ingress YAML: ${1}"
+    # We apply a filter here because when we're installing from a pre-built
+    # bundle then the whole bundle it passed here.  We use ko because it has
+    # better filtering support for CRDs.
+    ko apply -f "${1}" --selector=networking.knative.dev/ingress-provider=istio || return 1
+    UNINSTALL_LIST+=( "${1}" )
+  fi
 }
 
 function install_gloo() {
-  local gloo_base="./third_party/gloo-latest"
-  INSTALL_GLOO_YAML="${gloo_base}/gloo.yaml"
+  local INSTALL_GLOO_YAML="./third_party/gloo-latest/gloo.yaml"
   echo "Gloo YAML: ${INSTALL_GLOO_YAML}"
   echo ">> Bringing up Gloo"
 
   kubectl apply -f ${INSTALL_GLOO_YAML} || return 1
+  UNINSTALL_LIST+=( "${INSTALL_GLOO_YAML}" )
+
+  echo ">> Patching Gloo"
+  # Scale replicas of the Gloo proxies to handle large qps
+  kubectl scale -n gloo-system deployment knative-external-proxy --replicas=6
+  kubectl scale -n gloo-system deployment knative-internal-proxy --replicas=6
 }
 
 function install_kourier() {
-  local kourier_base="./third_party/kourier-latest"
-  INSTALL_KOURIER_YAML="${kourier_base}/kourier.yaml"
+  local INSTALL_KOURIER_YAML="./third_party/kourier-latest/kourier.yaml"
   echo "Kourier YAML: ${INSTALL_KOURIER_YAML}"
   echo ">> Bringing up Kourier"
 
   kubectl apply -f ${INSTALL_KOURIER_YAML} || return 1
+  UNINSTALL_LIST+=( "${INSTALL_KOURIER_YAML}" )
+
+  echo ">> Patching Kourier"
+  # Scale replicas of the Kourier gateways to handle large qps
+  kubectl scale -n kourier-system deployment 3scale-kourier-gateway --replicas=6
+}
+
+function install_ambassador() {
+  local AMBASSADOR_MANIFESTS_PATH="./third_party/ambassador-latest/"
+  echo "Ambassador YAML: ${AMBASSADOR_MANIFESTS_PATH}"
+
+  echo ">> Creating namespace 'ambassador'"
+  kubectl create namespace ambassador || return 1
+
+  echo ">> Installing Ambassador"
+  kubectl apply -n ambassador -f ${AMBASSADOR_MANIFESTS_PATH} || return 1
+  UNINSTALL_LIST+=( "${AMBASSADOR_MANIFESTS_PATH}" )
+
+  echo ">> Fixing Ambassador's permissions"
+  kubectl patch clusterrolebinding ambassador -p '{"subjects":[{"kind": "ServiceAccount", "name": "ambassador", "namespace": "ambassador"}]}' || return 1
+
+  echo ">> Enabling Knative support in Ambassador"
+  kubectl set env --namespace ambassador deployments/ambassador AMBASSADOR_KNATIVE_SUPPORT=true || return 1
+
+  echo ">> Patching Ambassador"
+  # Scale replicas of the Ambassador gateway to handle large qps
+  kubectl scale -n ambassador deployment ambassador --replicas=6
+}
+
+function install_contour() {
+  local INSTALL_CONTOUR_YAML="./third_party/contour-latest/contour.yaml"
+  echo "Contour YAML: ${INSTALL_CONTOUR_YAML}"
+  echo ">> Bringing up Contour"
+
+  kubectl apply -f ${INSTALL_CONTOUR_YAML} || return 1
+  UNINSTALL_LIST+=( "${INSTALL_CONTOUR_YAML}" )
 }
 
 # Installs Knative Serving in the current cluster, and waits for it to be ready.
@@ -196,54 +268,83 @@ function install_kourier() {
 # Parameters: $1 - Knative Serving YAML file
 #             $2 - Knative Monitoring YAML file (optional)
 function install_knative_serving_standard() {
-  INSTALL_RELEASE_YAML=$1
-  INSTALL_MONITORING_YAML=$2
+  readonly INSTALL_CERT_MANAGER_YAML="./third_party/cert-manager-${CERT_MANAGER_VERSION}/cert-manager.yaml"
+
+  echo ">> Creating knative-serving namespace if it does not exist"
+  kubectl get ns knative-serving || kubectl create namespace knative-serving
+
+  echo ">> Installing Knative CRD"
   if [[ -z "$1" ]]; then
-    # install_knative_serving_standard was called with no arg.
+    # If we need to build from source, then kick that off first.
     build_knative_from_source
-    INSTALL_RELEASE_YAML="${SERVING_YAML}"
 
-    # install serving core if installing for Gloo or Kourier
-    if [[ -n "${GLOO_VERSION}" || -n "${KOURIER_VERSION}" ]]; then
-      INSTALL_RELEASE_YAML="${SERVING_CORE_YAML}"
-    fi
-
-    if (( INSTALL_MONITORING )); then
-      INSTALL_MONITORING_YAML="${MONITORING_YAML}"
-    fi
+    echo "CRD YAML: ${SERVING_CRD_YAML}"
+    kubectl apply -f "${SERVING_CRD_YAML}" || return 1
+    UNINSTALL_LIST+=( "${SERVING_CRD_YAML}" )
+  else
+    echo "Knative YAML: ${1}"
+    ko apply -f "${1}" --selector=knative.dev/crd-install=true || return 1
+    UNINSTALL_LIST+=( "${1}" )
+    SERVING_ISTIO_YAML="${1}"
   fi
 
-  INSTALL_CERT_MANAGER_YAML="./third_party/cert-manager-${CERT_MANAGER_VERSION}/cert-manager.yaml"
-
-  echo ">> Installing Knative serving"
-  echo "Cert Manager YAML: ${INSTALL_CERT_MANAGER_YAML}"
-  echo "Knative YAML: ${INSTALL_RELEASE_YAML}"
-
-  # If no gateway was set on command line, assume Istio
-  if (( ! GATEWAY_SETUP )); then
-    echo ">> No gateway set up on command line, using Istio"
-    readonly ISTIO_VERSION="1.4-latest"
-  fi
-
-  if [[ -n "${ISTIO_VERSION}" ]]; then
-    install_istio
-  fi
+  echo ">> Installing Ingress"
   if [[ -n "${GLOO_VERSION}" ]]; then
     install_gloo
-  fi
-  if [[ -n "${KOURIER_VERSION}" ]]; then
+  elif [[ -n "${KOURIER_VERSION}" ]]; then
     install_kourier
+  elif [[ -n "${AMBASSADOR_VERSION}" ]]; then
+    install_ambassador
+  elif [[ -n "${CONTOUR_VERSION}" ]]; then
+    install_contour
+  else
+    install_istio "${SERVING_ISTIO_YAML}"
   fi
 
   echo ">> Installing Cert-Manager"
+  echo "Cert Manager YAML: ${INSTALL_CERT_MANAGER_YAML}"
   kubectl apply -f "${INSTALL_CERT_MANAGER_YAML}" --validate=false || return 1
+  UNINSTALL_LIST+=( "${INSTALL_CERT_MANAGER_YAML}" )
 
-  echo ">> Bringing up Serving"
-  kubectl apply -f "${INSTALL_RELEASE_YAML}" || return 1
+  echo ">> Installing Knative serving"
+  if [[ -z "$1" ]]; then
+    echo "Knative YAML: ${SERVING_CORE_YAML} and ${SERVING_HPA_YAML}"
+    kubectl apply \
+	    -f "${SERVING_CORE_YAML}" \
+	    -f "${SERVING_HPA_YAML}" || return 1
+    UNINSTALL_LIST+=( "${SERVING_CORE_YAML}" "${SERVING_HPA_YAML}" )
 
-  if [[ -n "${KOURIER_VERSION}" ]]; then
-    echo ">> Making Kourier the default ingress"
-    cat <<EOF | kubectl apply -f -
+    # ${SERVING_CERT_MANAGER_YAML} and ${SERVING_NSCERT_YAML} are set when calling
+    # build_knative_from_source
+    echo "Knative TLS YAML: ${SERVING_CERT_MANAGER_YAML} and ${SERVING_NSCERT_YAML}"
+    kubectl apply \
+      -f "${SERVING_CERT_MANAGER_YAML}" \
+      -f "${SERVING_NSCERT_YAML}" || return 1
+
+    if (( INSTALL_MONITORING )); then
+	echo ">> Installing Monitoring"
+	echo "Knative Monitoring YAML: ${MONITORING_YAML}"
+	kubectl apply -f "${MONITORING_YAML}" || return 1
+	UNINSTALL_LIST+=( "${MONITORING_YAML}" )
+    fi
+  else
+    echo "Knative YAML: ${1}"
+    # If we are installing from provided yaml, then only install non-istio bits here,
+    # and if we choose to install istio below, then pass the whole file as the rest.
+    # We use ko because it has better filtering support for CRDs.
+    ko apply -f "${1}" --selector=networking.knative.dev/ingress-provider!=istio || return 1
+    UNINSTALL_LIST+=( "${1}" )
+
+    if (( INSTALL_MONITORING )); then
+      echo ">> Installing Monitoring"
+      echo "Knative Monitoring YAML: ${2}"
+      kubectl apply -f "${2}" || return 1
+      UNINSTALL_LIST+=( "${2}" )
+    fi
+  fi
+
+  echo ">> Configuring the default Ingress: ${INGRESS_CLASS}"
+  cat <<EOF | kubectl apply -f -
 apiVersion: v1
 kind: ConfigMap
 metadata:
@@ -252,26 +353,8 @@ metadata:
   labels:
     serving.knative.dev/release: devel
 data:
-  ingress.class: "kourier.ingress.networking.knative.dev"
-  clusteringress.class: "kourier.ingress.networking.knative.dev"
+  ingress.class: ${INGRESS_CLASS}
 EOF
-  fi
-
-  if (( RECONCILE_GATEWAY )); then
-    echo ">> Turning on reconcileExternalGateway"
-    cat <<EOF | kubectl apply -f -
-apiVersion: v1
-kind: ConfigMap
-metadata:
-  name: config-istio
-  namespace: knative-serving
-  labels:
-    serving.knative.dev/release: devel
-    networking.knative.dev/ingress-provider: istio
-data:
-  reconcileExternalGateway: "true"
-EOF
-  fi
 
   echo ">> Turning on profiling.enable"
   cat <<EOF | kubectl apply -f -
@@ -284,48 +367,9 @@ data:
   profiling.enable: "true"
 EOF
 
-  echo ">> Patching activator hpa"
+  echo ">> Patching activator HPA"
   # We set min replicas to 2 for testing multiple activator pods.
   kubectl -n knative-serving patch hpa activator --patch '{"spec":{"minReplicas":2}}' || return 1
-
-  # post-install steps for istio
-  if [[ -n "${ISTIO_VERSION}" ]]; then
-    # Due to the lack of Status in Istio, we have to ignore failures in initial requests.
-    #
-    # However, since network configurations may reach different ingress pods at slightly
-    # different time, even ignoring failures for initial requests won't ensure subsequent
-    # requests will succeed all the time.  We are disabling ingress pod autoscaling here
-    # to avoid having too much flakes in the tests.  That would allow us to be stricter
-    # when checking non-probe requests to discover other routing issues.
-    #
-    # To compensate for this scaling down, we increase the CPU request for these pods.
-    #
-    # We should revisit this when Istio API exposes a Status that we can rely on.
-    # TODO(tcnghia): remove this when https://github.com/istio/istio/issues/882 is fixed.
-    echo ">> Patching Istio"
-    # There are reports of Envoy failing (503) when istio-pilot is overloaded.
-    # We generously add more pilot instances here to verify if we can reduce flakes.
-    if kubectl get hpa -n istio-system istio-pilot 2>/dev/null; then
-      kubectl patch hpa -n istio-system istio-pilot \
-        --patch '{"spec": {"minReplicas": 3, "maxReplicas": 10, "targetCPUUtilizationPercentage": 60}}' || return 1
-    else
-      # Some versions of Istio don't provide an HPA for pilot.
-      kubectl autoscale -n istio-system deploy istio-pilot --min=3 --max=10 --cpu-percent=60 || return 1
-    fi
-  elif [[ -n "${GLOO_VERSION}" ]]; then
-    # Scale replicas of the Gloo proxies to handle large qps
-    kubectl scale -n gloo-system deployment knative-external-proxy --replicas=6
-    kubectl scale -n gloo-system deployment knative-internal-proxy --replicas=6
-  elif [[ -n "${KOURIER_VERSION}" ]]; then
-    # Scale replicas of the Kourier gateways to handle large qps
-    kubectl scale -n kourier-system deployment 3scale-kourier-gateway --replicas=6
-  fi
-
-  if [[ -n "${INSTALL_MONITORING_YAML}" ]]; then
-    echo ">> Installing Monitoring"
-    echo "Knative Monitoring YAML: ${INSTALL_MONITORING_YAML}"
-    kubectl apply -f "${INSTALL_MONITORING_YAML}" || return 1
-  fi
 }
 
 # Check if we should use --resolvabledomain.  In case the ingress only has
@@ -344,9 +388,18 @@ function use_https() {
   fi
 }
 
+# Check if we should specify --ingressClass
+function ingress_class() {
+  if [[ -z "${INGRESS_CLASS}" ]]; then
+    echo ""
+  else
+    echo "--ingressClass=${INGRESS_CLASS}"
+  fi
+}
+
 # Uninstalls Knative Serving from the current cluster.
 function knative_teardown() {
-  if [[ -z "${INSTALL_CUSTOM_YAMLS}" && -z "${INSTALL_RELEASE_YAML}" ]]; then
+  if [[ -z "${INSTALL_CUSTOM_YAMLS}" && -z "${UNINSTALL_LIST[@]}" ]]; then
     echo "install_knative_serving() was not called, nothing to uninstall"
     return 0
   fi
@@ -358,19 +411,12 @@ function knative_teardown() {
     done
   else
     echo ">> Uninstalling Knative serving"
-    echo "Istio YAML: ${INSTALL_ISTIO_YAML}"
-    echo "Cert-Manager YAML: ${INSTALL_CERT_MANAGER_YAML}"
-    echo "Knative YAML: ${INSTALL_RELEASE_YAML}"
-    echo ">> Bringing down Serving"
-    ko delete --ignore-not-found=true -f "${INSTALL_RELEASE_YAML}" || return 1
-    if [[ -n "${INSTALL_MONITORING_YAML}" ]]; then
-      echo ">> Bringing down monitoring"
-      ko delete --ignore-not-found=true -f "${INSTALL_MONITORING_YAML}" || return 1
-    fi
-    echo ">> Bringing down Istio"
-    kubectl delete --ignore-not-found=true -f "${INSTALL_ISTIO_YAML}" || return 1
-    echo ">> Bringing down Cert-Manager"
-    kubectl delete --ignore-not-found=true -f "${INSTALL_CERT_MANAGER_YAML}" || return 1
+    for i in ${!UNINSTALL_LIST[@]}; do
+	# We uninstall elements in the reverse of the order they were installed.
+	local YAML="${UNINSTALL_LIST[$(( ${#array[@]} - $i ))]}"
+	echo ">> Bringing down YAML: ${YAML}"
+	kubectl delete --ignore-not-found=true -f "${YAML}" || return 1
+    done
   fi
 }
 
@@ -394,9 +440,16 @@ function test_setup() {
   if (( MESH )); then
     kubectl label namespace serving-tests istio-injection=enabled
     kubectl label namespace serving-tests-alt istio-injection=enabled
+    ko apply ${KO_FLAGS} -f test/config/mtls/ || return 1
   fi
+
+  echo ">> Uploading test images..."
   ${REPO_ROOT_DIR}/test/upload-test-images.sh || return 1
+
+  echo ">> Waiting for Serving components to be running..."
   wait_until_pods_running knative-serving || return 1
+
+  echo ">> Waiting for Ingress provider to be running..."
   if [[ -n "${ISTIO_VERSION}" ]]; then
     wait_until_pods_running istio-system || return 1
     wait_until_service_has_external_ip istio-system istio-ingressgateway
@@ -417,7 +470,25 @@ function test_setup() {
     wait_until_pods_running kourier-system || return 1
     wait_until_service_has_external_ip kourier-system kourier-external
   fi
-  if [[ -n "${INSTALL_MONITORING_YAML}" ]]; then
+  if [[ -n "${AMBASSADOR_VERSION}" ]]; then
+    # we must set these override values to allow the test spoofing client to work with Ambassador
+    # see https://github.com/knative/pkg/blob/release-0.7/test/ingress/ingress.go#L37
+    export GATEWAY_OVERRIDE=ambassador
+    export GATEWAY_NAMESPACE_OVERRIDE=ambassador
+    wait_until_pods_running ambassador || return 1
+    wait_until_service_has_external_ip ambassador ambassador
+  fi
+  if [[ -n "${CONTOUR_VERSION}" ]]; then
+    # we must set these override values to allow the test spoofing client to work with Contour
+    # see https://github.com/knative/pkg/blob/release-0.7/test/ingress/ingress.go#L37
+    export GATEWAY_OVERRIDE=envoy-external
+    export GATEWAY_NAMESPACE_OVERRIDE=projectcontour
+    wait_until_pods_running projectcontour || return 1
+    wait_until_service_has_external_ip projectcontour envoy-external
+  fi
+
+  if (( INSTALL_MONITORING )); then
+    echo ">> Waiting for Monitoring to be running..."
     wait_until_pods_running knative-monitoring || return 1
   fi
 }
@@ -426,7 +497,9 @@ function test_setup() {
 function test_teardown() {
   echo ">> Removing test resources (test/config/)"
   ko delete --ignore-not-found=true --now -f test/config/
-  (( MESH )) && ko delete --ignore-not-found=true --now -f test/config/mtls/
+  if (( MESH )); then
+    ko delete --ignore-not-found=true --now -f test/config/mtls/
+  fi
   echo ">> Ensuring test namespaces are clean"
   kubectl delete all --all --ignore-not-found --now --timeout 60s -n serving-tests
   kubectl delete --ignore-not-found --now --timeout 60s namespace serving-tests
